# PyQwidgets 5.0

Данный модуль основан на других библеотеках.

Этот модуль является уневерсальным!

## Чего нового?

- QR code 
- Исправления ошибок

## Виджеты

<code>PyQwidgets.Error(name, text)</code> - Создаёт окно ошибки.

<code>PyQwidgets.Warning(name, text)</code> - Создаёт окно предупреждения.

<code>PyQwidgets.Info(name, text)</code> - Создаёт окно информации.

<code>PyQwidgets.Screenshot(namefile)</code> - Делает скриншот.

<code>PyQwidgets.Download(url, namefile)</code> - Скачивает файлы с интернета.

<code>PyQwidgets.Open(url)</code> - Открывает веб-страницу

<code>PyQwidgets.QRCode(namefile, link)</code> - Создаёт QR код

## Доп.инфо

Данный модуль ещё находится в разработке и я новичок в питоне и по это-му модуль в разработке!

## Об авторе

Имя: **Георгий**

Фамилия: **Задворнов**

Почта: zadvornow2908@gmail.com